==> jpf-4.0.20.tgz: package/README.md <==
# JPF   (Javascript Presentation Foundation)
Library for building Graphical User Interfaces for the web following the MVVM pattern similar to WPF for Windows. 
The library contains baseclasses for "View" and "ViewModel" that have build in support for the observable pattern. 
So if a property in the ViewModel is observable and changes its value the View will automatically update itself. 

# Goals of this library
When moving away from server-side rendering to client-side rendering I found myself going back in time if it comes to RAD support in tooling. 
If we compare this to rich-client development like for example WPF or server side rendering like old fashioned ASP.Net forms or MVC we have lost a lot of support in our tooling on the way. 
When working with client-side rendering frameworks that are popular today I have learned that preventing me from making mistakes while writing my code is limited. 
I feel that defining a view in some sort of html text template enhanced with binding expressions is cumbersome. 
The tooling support to make sure that the View with its binding expressions is in sink with its ViewModel is very limited. 

#### So the main goals for this library are:

1. **Support the MVVM design pattern**
1. **Have a clear separation between GUI logic and presentation. Separation of concern View, ViewModel**
1. **Being able to change the presentation without affecting the GUI logic. Change the View without affecting the ViewModel**
1. **Sharing the same GUI logic for multiple presentations. Having one ViewModel with multiple Views for example for Desktop and Mobile**
1. **Eliminate the use of text based templating**
1. **Support binding expression checking at compile time** 
1. **Discover programming errors at compile time instead of runtime**

==> jpf-4.0.24.tgz: package/README.md <==
# JPF   (Javascript Presentation Foundation)
Library for building Graphical User Interfaces for the web following the MVVM pattern similar to WPF for Windows. 
The library contains baseclasses for "View" and "ViewModel" that have build in support for the observable pattern. 
So if a property in the ViewModel is observable and changes its value the View will automatically update itself. 

# Goals of this library
When moving away from server-side rendering to client-side rendering I found myself going back in time if it comes to RAD support in tooling. 
If we compare this to rich-client development like for example WPF or server side rendering like old fashioned ASP.Net forms or MVC we have lost a lot of support in our tooling on the way. 
When working with client-side rendering frameworks that are popular today I have learned that preventing me from making mistakes while writing my code is limited. 
I feel that defining a view in some sort of html text template enhanced with binding expressions is cumbersome. 
The tooling support to make sure that the View with its binding expressions is in sink with its ViewModel is very limited. 

#### So the main goals for this library are:

1. **Support the MVVM design pattern**
1. **Have a clear separation between GUI logic and presentation. Clear separation of concern between View and ViewModel**
1. **Being able to change the presentation without affecting the GUI logic. Changing the View without affecting the ViewModel**
1. **Sharing the same GUI logic for multiple presentations. Having one ViewModel with multiple Views for example for Desktop and Mobile**
1. **Eliminate the use of text based templating**
1. **Support binding expression checking at development time instead of runtime** 
1. **Discover programming errors at compile time instead of runtime**
